@@ -49,9 +49,10 @@ void Kwave::StringEnterPlugin::load(QStringList &params)
 {
     Q_UNUSED(params);
     QString entry = _("menu(plugin:setup(stringenter),%1/%2,F12)");
-    emitCommand(entry.arg(
-	_(I18N_NOOP("Settings"))).arg(_(I18N_NOOP("Enter Command")))
-    );
+    emitCommand(entry.arg(_("Settings")).arg(_(I18N_NOOP2(
+        "menu: /Settings/Enter Command",
+                        "Enter Command")
+    )));
 }
 
 //***************************************************************************
